#
# spec file for package spglib
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shlib libsymspg1
Name:           spglib
Version:        2.0.2
Release:        bp156.2.4
Summary:        Find and handle crystal symmetries
License:        BSD-3-Clause
Group:          Productivity/Scientific/Physics
URL:            https://spglib.github.io/spglib/
Source0:        https://github.com/spglib/spglib/archive/v%{version}.tar.gz#/spglib-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-setuptools

%description
Spglib is a C library to find and handle crystal symmetries.

Features:
 * Find symmetry operations
 * Identify space-group type
 * Wyckoff position assignment
 * Refine crystal structure
 * Search irreducible k-points
 * Find a primitive cell

%package -n %{shlib}
Summary:        The shared library for SPGLIB
Group:          System/Libraries

%description -n %{shlib}
Spglib is a C library to find and handle crystal symmetries.

%package devel
Summary:        Development files for spglib/libsymspg
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}

%description devel
Spglib is a C library to find and handle crystal symmetries.

%package -n python3-spglib
Summary:        Python bindings for spglib/libsymspg
Group:          Development/Languages/Python
Requires:       python3-numpy

%description -n python3-spglib
Spglib is a C library to find and handle crystal symmetries.

%prep
%setup -q
%autopatch -p1

%build
pushd .
%cmake
%cmake_build
popd

pushd python
%python3_build
popd

%install
pushd .
%cmake_install
rm %{buildroot}%{_libdir}/lib*.a
popd

# Fix "env-script-interpreter" rpmlint warning
chmod 644 ruby/*.rb

pushd python
%python3_install
popd

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%license COPYING
%{_libdir}/libsymspg.so.*

%files devel
%doc example ruby
%{_includedir}/spglib.h
%{_includedir}/spglib_f08.f90
%{_libdir}/libsymspg.so
%{_libdir}/pkgconfig/spglib.pc

%files -n python3-spglib
%{python3_sitearch}/spglib
%{python3_sitearch}/spglib*.egg-info

%changelog
* Sat Dec  3 2022 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  * Fix segmentation fault in spgms_get_symmetry_with_site_tensors with high symprec
  * Fix possible segmentation fault in get_magnetic_dataset with high symprec
* Sun Sep 11 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 2.0.1:
  See https://spglib.github.io/spglib/releases.html
- Drop upstreamed 0001-Install-spglib-pkgconfig-into-LIBDIR.patch
* Sun Aug  7 2022 Dirk Müller <dmueller@suse.com>
- update to 1.16.5:
  * Maintenance release including many minor fixes and improvements
  * Bug fix of issue #157
- add 0001-Install-spglib-pkgconfig-into-LIBDIR.patch to fix
  pkgconfig installation location
* Mon Dec 20 2021 Dirk Müller <dmueller@suse.com>
- update to 1.16.3:
  * Collection of fixes and improvements.
  * Fix wyckoff position database.
  * Fix Delaunay reduction.
  * Improvements of fortran interface.
  * Added standardize_cell to fortran interface.
* Sat Jul 17 2021 Dirk Müller <dmueller@suse.com>
- update to 1.16.1:
  * Bug fix of fortran wrapper.
  * Minor update. Symmetry operations in spg_database.c for
    Hall numbers 212, 213, 214 are re-ordered to start by identity
    operation.
- drop 0001-Fix-CMakeLists.txt.patch (upstream)
* Fri Feb 28 2020 andy great <andythe_great@pm.me>
- Fix "env-script-interpreter" rpmlint warning
* Fri Feb 28 2020 andy great <andythe_great@pm.me>
- Clean spec file.
* Thu Feb 13 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Build and package python3 bindings.
- Switch to cmake build, autoconf will be removed in the
  next version.
  * Add 0001-Fix-CMakeLists.txt.patch
* Thu Feb 13 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 1.14.1
  * Version number increment just to release pypi package.
- Update to version 1.14
  * Improvement against cyclic point change over applying
    standardizaion repeatedly.
- Update to version 1.13
  * Fix Issue#57 of SeekPath: Standardizations of choices of a,b,c
    axes for Cmma (67), Ccca(68), Ibca(73), Imma(74) were fixed.
    For monoclinic systems, lengths of non-unique axes are now
    checked by an exhaustive way.
  * Issue#79: Treatment of ir-kpoint search for special cases with
    three fold rotation (e.g., hexagonal or primitive FCC).
- Update to version 1.12.2
  * Minor release for memory leak fix (PR#71).
- Update to version 1.12.1
  * Bug fix of PR #70. #include <stddef.h> is inserted. In
    principle, this line is necessary to compile.
- Update to version 1.12.2
  * After this minor version, addition of new features will be
    stopped until version 2.0 will be released.
  * Experimental support of site symmetry symbols.
  * Comparisons of basis vector lengths are more carefully done
    for letting them work for different computer architectures to
    treat very small numerical different that is close to the
    machine precision.
  * Similarly, MOD-Z operation (bring values x inside the rage of
    0<= x < 1) is now done considering the difference of machine
    precision.
  * To enable dense k-point mesh sampling, integer types of
    variables that represent grid point indices were changed from
    int to size_t.
- Update to version 1.11.2
  * Bug fix. Again, origin shift was still not correctly computed
    when the standardized basis vectors are rotated in this method
    to find most similar choice of basis vectors to the idealized
    ones.
- Update to version 1.11.1
  * Bug fix. Origin shift was not correctly computed when the
    standardized basis vectors are rotated in this method to find
    most similar choice of basis vectors to the idealized ones.
    This bug affected to 'origin_shift' and 'std_positions' in
    spglib dataset and the functions 'spg_standardize_cell',
    'spg_find_primitive', and 'spg_refine_cell'.
- Update to version 1.11.0
  * This looks for a similar choice of starndardized basis vectors
    to that of idealized starndardized basis vectors among those
    generated by proper symmetry operations.
  * This computes a rigid rotation matrix introduced
    in the idealization step. The rotation is made to agree a-axes
    and a-b planes between systems before and after idealization.
- Update to version 1.10.4
  * Collection of minor fixes.
    A text on spglib algorithm is prepared for this version. This
    text will be available soon at arXiv. To be consistent between
    text and code, the code refactoring was made.
- Update to version 1.10.3
  * New algorithm to search translation part of space group
    operation is implmented by Michael Lamparski to improving the
    search speed especially for large unit cell systems. For this,
    new files 'overlap.*' are added and so the version number is
    incremented.
- Update to version 1.10.2
  * Automake didn't work due to the lack of determination.{c,h}
    lines. This was fixed.
- Update to version 1.10.1
  * A large refactoring was made to replace the outer-most
    iteration loop of symmetry search algorithm to a new file
    'determination.c'.
  * These routines had accessed directly to a function close to
    spacegroup.c. Now these are replaced by passing through
    'get_dataset'.
- Update to version 1.10.0
  * 'mapping_to_primitive' and 'std_mapping_to_primitive' in the
    spglib dataset are put available on the spglib
    document. 'spg_get_hall_number_from_symmetry' function
    ('get_hall_number_from_symmetry' method for python) is also
- Update to version 1.9.10
  * Pure translation search is made faster using a property of
    group, which is significantly effective for supercells with
    large multiplicity.
* Wed Dec 21 2016 tittiatcoke@gmail.com
- Initial package based on 1.9.9
